@@ -22,6 +22,10 @@
 
 #include "ldns/util.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /**
  * number of initial bytes in buffer of
  * which we cannot tell the size before hand
@@ -603,8 +607,8 @@ ldns_buffer_status_ok(ldns_buffer *buffer)
 
 /**
  * prints to the buffer, increasing the capacity if required using
- * buffer_reserve(). The buffer's position is set to the terminating
- * '\\0'. Returns the number of characters written (not including the
+ * buffer_reserve(). The buffer's position is set to the terminating '\\0'
+ * Returns the number of characters written (not including the
  * terminating '\\0') or -1 on failure.
  */
 int ldns_buffer_printf(ldns_buffer *buffer, const char *format, ...);
@@ -633,4 +637,8 @@ void *ldns_buffer_export(ldns_buffer *buffer);
  */
 void ldns_buffer_copy(ldns_buffer* result, ldns_buffer* from);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* LDNS_BUFFER_H */
