@@ -23,6 +23,10 @@
 #include <ldns/buffer.h>
 #include <ldns/error.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /** Maximum length of a dname label */
 #define LDNS_MAX_LABELLEN     63
 /** Maximum length of a complete dname */
@@ -172,6 +176,7 @@ enum ldns_enum_rr_type
 	LDNS_RR_TYPE_DHCID = 49,
 
 	LDNS_RR_TYPE_NSEC3 = 50,
+	LDNS_RR_TYPE_NSEC3PARAM = 51,
 	LDNS_RR_TYPE_NSEC3PARAMS = 51,
 
         /** draft-ietf-dnsop-trust-history */
@@ -874,4 +879,8 @@ ldns_rr_list_type(const ldns_rr_list *rr_list);
 ldns_rdf *
 ldns_rr_list_owner(const ldns_rr_list *rr_list);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* LDNS_RR_H */
